@@ -11,7 +11,7 @@ use Moo;
 use IPC::Run3; # For run3().
 use Types::Standard qw/Any ArrayRef HasMethods HashRef Int Str/;
 
-our $VERSION = '2.61';
+our $VERSION = '2.62';
 
 my $DATA_SECTION = get_data_section; # load once
 my $DEFAULT_COMBINE = 1; # default for combine_node_and_port
@@ -435,26 +435,9 @@ sub escape_port {
 
 sub escape_some_chars {
 	my ($s, $quote_chars) = @_;
-	my @s        = split(//, $s);
-	my $label    = '';
-	for my $i (0 .. $#s) {
-		my $maybe = 0;
-		if ( ($s[$i] eq '[') || ($s[$i] eq ']') ) {
-			$maybe = 1;
-		} elsif ($s[$i] eq '"') {
-			if (substr($s, 0, 1) ne '<') {
-				$maybe = 1; # It's not a HTML label
-			}
-		} elsif ($quote_chars and $s[$i] =~ /[$quote_chars]/) {
-			$maybe = 1;
-		}
-		# Escape if not escaped.
-		if ($maybe && (($i == 0) || (($i > 0) && ($s[$i - 1] ne '\\')))) {
-			$label .= '\\';
-		}
-		$label .= $s[$i];
-	}
-	return $label;
+	return $s if substr($s, 0, 1) eq '<'; # HTML label
+	$s =~ s/(\\.)|([$quote_chars])/ defined($1) ? $1 : '\\' . $2 /ge;
+	return $s;
 }
 
 sub log
